@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-__version__ = '0.9.5.post24'
-__timestamp__ = 'Wed Jan 6 10:55:03 2021 +0000'
+__version__ = '0.9.6'
+__timestamp__ = 'Thu Apr 29 15:18:54 2021 +0100'
 __license__ = '''
                                  Apache License
                            Version 2.0, January 2004
