@@ -42,6 +42,7 @@ except ImportError:
 
 from quantiphyse.utils import sf, QpException
 from quantiphyse.utils.enums import Visibility, Boundary
+from quantiphyse.gui.colors import DEFAULT_CMAP, DEFAULT_CMAP_ROI
 
 # Private copy of pyqtgraph functions for bug fixes
 from . import functions as pg
@@ -353,7 +354,7 @@ DEFAULT_DATA_VIEW = {
     "boundary" : Boundary.TRANS,
     "alpha" : 255,
     "interp_order" : 0,
-    "cmap" : "jet",
+    "cmap" : DEFAULT_CMAP,
     "z_order" : 0,
 }
 
@@ -365,7 +366,7 @@ DEFAULT_ROI_VIEW = {
     "shade" : True,
     "contour" : False,
     "interp_order" : 0,
-    "cmap" : "jet",
+    "cmap" : DEFAULT_CMAP_ROI,
     "z_order" : 0,
 }
 
@@ -468,8 +469,6 @@ class QpData(object):
             roi = md_roi
             
         self.view = Metadata()
-        if view is not None:
-            self.view.update(view)
 
         self._meta["fname"] = kwargs.get("fname", None)
         self._meta["vol_scale"] = kwargs.get("vol_scale", 1.0)
@@ -484,6 +483,9 @@ class QpData(object):
         else:
             self.roi = roi
 
+        if view is not None:
+            self.view.update(view)
+
     @property
     def metadata(self):
         """ Metadata dictionary """
@@ -735,7 +737,7 @@ class QpData(object):
         exactly zero (Issue #101)
         """
         if self.roi:
-            return 0.1, max(self.regions.keys())
+            return 1, max(self.regions.keys())
         else:
             cmin, cmax = self.range(vol, percentile, roi)
             if cmin == 0:
