@@ -43,7 +43,7 @@ except ImportError:
 from quantiphyse.data.extras import NumberListExtra
 from quantiphyse.utils import QpException, sf, load_matrix, local_file_from_drop_url, default_save_dir, set_default_save_dir
 from quantiphyse.gui.viewer.pickers import PickMode
-from quantiphyse.gui.dialogs import MatrixViewerDialog, ChooseFromListDialog
+from quantiphyse.gui.dialogs import MatrixViewerDialog, ChooseFromListDialog, PlotDialog1d
 
 LOG = logging.getLogger(__name__)
 
@@ -62,6 +62,8 @@ class OptionBox(QtGui.QGroupBox):
         self._current_row = 0
         self._options = {}
         self._rows = {}
+        # For checked options
+        self.grid.setColumnStretch(2, 1)
 
     def add(self, label, *options, **kwargs):
         """
@@ -1047,6 +1049,7 @@ class NumberListOption(Option, QtGui.QWidget):
     def __init__(self, initial=(), intonly=False, load_btn=True, extras_btn=False, ivm=None):
         QtGui.QWidget.__init__(self)
         self._ivm = ivm
+        self._value = []
         self._hbox = QtGui.QHBoxLayout()
         self._hbox.setContentsMargins(0, 0, 0, 0)
         self.setLayout(self._hbox)
@@ -1070,26 +1073,24 @@ class NumberListOption(Option, QtGui.QWidget):
             self._type = float
         self.value = initial
         self._edit.editingFinished.connect(self._edit_changed)
+        self.setAcceptDrops(True)
 
     @property
     def value(self):
         """ List of numbers or empty list if invalid data entered """
-        try:
-            text = self._edit.text().replace(",", " ")
-            return [self._type(v) for v in text.split()] 
-        except ValueError:
-            return []
+        return self._value
 
     @value.setter
     def value(self, vals):
-        self._edit.setText(" ".join([str(v) for v in vals]))
+        self._edit.setText(" ".join([str(v) for v in self._value]))
+        self._value = vals
         self._edit_changed()
 
     def _edit_changed(self):
         try:
             text = self._edit.text().replace(",", " ")
-            numbers = [self._type(v) for v in text.split()]
-            self._edit.setText(" ".join([str(v) for v in numbers]))
+            self._value = [self._type(v) for v in text.split()]
+            self._edit.setText(" ".join([str(v) for v in self._value]))
             self._edit.setStyleSheet("")
         except ValueError:
             # Colour edit red but don't change anything
@@ -1137,7 +1138,8 @@ class NumberListOption(Option, QtGui.QWidget):
             event.setDropAction(QtCore.Qt.CopyAction)
             event.accept()
             for url in event.mimeData().urls():
-                self._load_file(local_file_from_drop_url(url))
+                local_file = local_file_from_drop_url(url)
+                self._load_file(local_file)
         else:
             event.ignore()
 
@@ -1254,7 +1256,7 @@ class FileOption(Option, QtGui.QWidget):
     """
     sig_changed = QtCore.Signal()
 
-    def __init__(self, dirs=False, initial=""):
+    def __init__(self, dirs=False, initial="", plot_btn=False):
         """
         :param dirs: If True, allow only directories to be selected
         """
@@ -1262,13 +1264,22 @@ class FileOption(Option, QtGui.QWidget):
         self._dirs = dirs
 
         hbox = QtGui.QHBoxLayout()
+        hbox.setContentsMargins(0, 0, 0, 0)
         self.setLayout(hbox)
         self._edit = QtGui.QLineEdit(initial)
         hbox.addWidget(self._edit)
+
         self._btn = QtGui.QPushButton("Choose")
         self._btn.clicked.connect(self._clicked)
         hbox.addWidget(self._btn)
 
+        if plot_btn:
+            plot_btn = QtGui.QPushButton("Plot")
+            plot_btn.clicked.connect(self._plot)
+            hbox.addWidget(plot_btn)
+
+        self.setAcceptDrops(True)
+
     @property
     def value(self):
         """ Return path of selected file """
@@ -1279,6 +1290,36 @@ class FileOption(Option, QtGui.QWidget):
         """ Set the path. Note no validation? """
         self._edit.setText(path)
 
+    def dragEnterEvent(self, event):
+        """ Called when item is dragged into the filename edit"""
+        if event.mimeData().hasUrls:
+            event.accept()
+        else:
+            event.ignore()
+
+    def dragMoveEvent(self, event):
+        """ Called when item is dragged over the filename edit"""
+        if event.mimeData().hasUrls:
+            event.setDropAction(QtCore.Qt.CopyAction)
+            event.accept()
+        else:
+            event.ignore()
+
+    def dropEvent(self, event):
+        """
+        Called when item is dropped onto the filename edit
+
+        If it's a filename-like item, accept.
+        """
+        if event.mimeData().hasUrls:
+            event.setDropAction(QtCore.Qt.CopyAction)
+            event.accept()
+            for url in event.mimeData().urls():
+                self._edit.setText(local_file_from_drop_url(url))
+                self.sig_changed.emit()
+        else:
+            event.ignore()
+
     def _clicked(self):
         if self._dirs:
             path = QtGui.QFileDialog.getExistingDirectory(parent=self, dir=self.value)
@@ -1287,6 +1328,21 @@ class FileOption(Option, QtGui.QWidget):
         self._edit.setText(path)
         self.sig_changed.emit()
 
+    def _plot(self):
+        try:
+            try:
+                arr = np.loadtxt(self.value)
+            except ValueError as exc:
+                arr = np.loadtxt(self.value, delimiter=",")
+        except ValueError as exc:
+            raise QpException("Data in file was not a numeric array: %s" % str(exc))
+
+        if arr.ndim != 1:
+            raise QpException("Can't plot data with > 1 dimensions")
+
+        plot_dialog = PlotDialog1d(self, arr, title=self.value)
+        plot_dialog.exec_()
+
 class RunButton(QtGui.QWidget):
     """
     A button which, when clicked, runs an analysis process
