@@ -166,7 +166,7 @@ class SliceDataView(LogSource):
             # Update data and level for existing contour items, and create new ones if needed
             max_region = max(self._qpdata.regions.keys())
             for val in self._qpdata.regions:
-                pencol = get_col(self._lut, val, max_region)
+                pencol = get_col(self._lut, val, (1, max_region))
                 if val != 0:
                     if n_contours == len(self._contours):
                         self._contours.append(pg.IsocurveItem())
@@ -316,14 +316,16 @@ class OrthoSliceViewer(pg.GraphicsView, LogSource):
         self.reset()
 
     def _focus_changed(self, focus):
-        self.debug("focus=%s", focus)
+        self.debug("focus=%s, zaxis=%i", focus, self.zaxis)
 
         if self.isVisible():
             self._vline.setPos(float(focus[self.xaxis]))
             self._hline.setPos(float(focus[self.yaxis]))
 
             if focus[self.zaxis] != self._slicez or self._vol != focus[3]:
+                self.debug("updating slice")
                 self._update_slice()
+                self.debug("updating arrows")
                 self._update_visible_arrows()
 
     def _arrows_changed(self, arrows):
